@@ -5,13 +5,16 @@ import (
 	"strings"
 
 	"github.com/miekg/dns"
+	"github.com/mr-karan/doggo/pkg/models"
 )
 
 // LoadFallbacks sets fallbacks for options
 // that are not specified by the user but necessary
 // for the resolver.
 func (app *App) LoadFallbacks() {
-	if len(app.QueryFlags.QTypes) == 0 {
+	if app.QueryFlags.QueryAny {
+		app.QueryFlags.QTypes = models.GetCommonRecordTypes()
+	} else if len(app.QueryFlags.QTypes) == 0 {
 		app.QueryFlags.QTypes = append(app.QueryFlags.QTypes, "A")
 	}
 	if len(app.QueryFlags.QClasses) == 0 {
